interval_to_internal

Function interval_to_internal 

pub const fn interval_to_internal(size: usize) -> usize
Calculates the number of internal nodes from interval size. Rounds to nearest power of two to generate a complete binary tree.