interval_to_nodes

Function interval_to_nodes 

pub const fn interval_to_nodes(size: usize) -> usize
Calculates how many nodes an interval tree should have for the given interval size. Rounds to nearest power of two to generate a complete binary tree.