nodes_to_bitfields

Function nodes_to_bitfields 

pub const fn nodes_to_bitfields(nodes: usize) -> usize
Calculates with how many bitfields an interval tree should be backed by to hold the given number of nodes.